/* This lists all the keys on the PGP keyring */
/* and extracts the key data for a particular */
/* user                                       */

#import <stdio.h>
#import <stdlib.h>
#import <pgp.h>
#import <Foundation/Foundation.h>
#import <Foundation/NSString.h>
#import <Foundation/NSData.h>
#import <PGPserver.h>

int main(int argc, char *argv[])
{
    PGPserver *pgpCryptor;
    NSMutableArray *userIDArray;
    NSData *keyData;
    NSString *keyString;
    NSString *userID = NSUserName();
    int i,nusers,pgpError;
    id pool = [[NSAutoreleasePool alloc] init];

    /* Initialize a cryptor object */
    pgpCryptor = [[PGPserver alloc] init];

    if(pgpCryptor == nil) {
	fprintf(stderr,"Could not initialize a PGP cryptor.  See console for details\n");
	exit(1);
    }

    /* Just for the fun of it, let's get all the userIDs on the keyring */
    userIDArray = [pgpCryptor getAllUserIDs:&pgpError];

    /* And print them out */
    fprintf(stderr," Found %d userIDs on pgpKeyRing:\n",[userIDArray count]);

    for(i=0; i<[userIDArray count]; i++) {
	fprintf(stderr,"   %s\n",[[userIDArray objectAtIndex:i] cString]);
    }
    fprintf(stderr,"\n\n");


    /* Now, let's check for specific userID */
    nusers = [pgpCryptor userIDExists:userID error:&pgpError];

    if(nusers > 0)
      fprintf(stderr,"There are %d instances of user name %s on keyring\n",
	      nusers,[userID cString]);
    else
	fprintf(stderr,"User %s does not exist on keyring\n",[userID cString]);


    /* Extract the key for user */
    keyData = [pgpCryptor exportKeyData:userID error:&pgpError];

    if(pgpError != 0) {
	fprintf(stderr,"PGP Error %d extracting key for user %s.  See console for details\n",
		pgpError,[userID cString]);
	exit(1);
    }

    /* Print the key data */
    keyString = [[NSString alloc] initWithData:keyData encoding:NSASCIIStringEncoding];
    printf("PGP Key for %s:\n\n",[userID cString]);
    printf("%s\n\n",[keyString cString]);


    /* Clean up, get out */
    [keyString release];
    [pgpCryptor release];
    [pool release];

    exit(0);
}
