/* This program will verify a detached signature */
/* with its associated data file                 */

#import <stdio.h>
#import <stdlib.h>
#import <Foundation/Foundation.h>
#import <pgp.h>
#import <PGPserver.h>

int main(int argc, char *argv[])
{
    PGPserver *pgpCryptor;
    id docData,sigData;
    int sigStat,pgpError;
    NSString *signator;
    NSDate *sigDate;
    id pool = [[NSAutoreleasePool alloc] init];

    /* Initialize a cryptor object */
    pgpCryptor = [[PGPserver alloc] init];

    if(pgpCryptor == nil) {
	fprintf(stderr,"Could not initialize a PGP cryptor.  See console for details\n");
	exit(1);
    }

    /* Initialize a signed data object.  This expects a detached     */
    /* signature file in 'plainFile.asc', and its corresponding      */
    /* data file to be in 'plainFile.tx'.  You can generate a sample */
    /* detached signature data file using the signDetached           */
    /* program in this directory, and directing its output to        */
    /* a file named 'plainFile.asc'                                  */

    sigData = [NSData dataWithContentsOfFile:@"./plainFile.asc"];
    docData = [NSData dataWithContentsOfFile:@"./plainFile.txt"];

    /* Verify signature */
    [pgpCryptor verifyDetachedSignatureData:sigData
		                againstData:docData 
 		                 passPhrase:@""
		                      error:&pgpError];

    if(pgpError) {
	fprintf(stderr,"MAIN:  PGP Error %d on Signature Verify\n",pgpError);
	exit(1);
    }

    sigStat = [pgpCryptor signatureStatus];
    if(sigStat == PGP6_GOODSIG) {
	signator = [pgpCryptor signator];
	sigDate = [pgpCryptor signatureDate];
	fprintf(stderr,"GOOD SIGNATURE\n");
	fprintf(stderr,"    Signator:  %s\n",[signator cString]);
	fprintf(stderr,"        Date:  %s\n",[[sigDate description] cString]);
    }
    else if(sigStat == PGP6_NOSIG) {
	fprintf(stderr,"NO SIGNATURE on this document\n");
    }
    else if(sigStat == PGP6_BADSIG) {
	fprintf(stderr,"BAD SIGNATURE\n");
    }
    else if(sigStat == PGP6_SIGNOKEY) {
	fprintf(stderr,"UNVERIFIED SIGNATURE, NO PUBLIC KEY\n");
    }
	

    [pgpCryptor release];
    [pool release];

    exit(0);
}
