/* This program will verify a signed text buffer */

#import <stdio.h>
#import <stdlib.h>
#import <Foundation/Foundation.h>
#import <pgp.h>
#import <PGPserver.h>

int main(int argc, char *argv[])
{
    PGPserver *pgpCryptor;
    NSData *sigData;
    int sigStat,pgpError;
    NSString *signator;
    NSDate *sigDate;
    id pool = [[NSAutoreleasePool alloc] init];

    /* Initialize a cryptor object */
    pgpCryptor = [[PGPserver alloc] init];

    if(pgpCryptor == nil) {
	fprintf(stderr,"Could not initialize a PGP cryptor.  See console for details\n");
	exit(1);
    }

    /* Initialize a signed data object.  This expects a PGP signed  */
    /* data file in 'tstFile.asc'.  You can generate a sample       */
    /* signed file using the 'sign' test program in this directory, */
    /* and redirecting its output to a file named 'tstFile.asc'     */

    sigData = [NSData dataWithContentsOfFile:@"./tstFile.asc"];

    /* Verify clear-signed signature */
    [pgpCryptor verifySignatureData:sigData
	                 passPhrase:nil
	                      error:&pgpError];

    if(pgpError) {
	fprintf(stderr,"MAIN:  PGP Error %d on Signature Verify\n",pgpError);
	exit(1);
    }

    sigStat = [pgpCryptor signatureStatus];
    if(sigStat == PGP6_GOODSIG) {
	signator = [pgpCryptor signator];
	sigDate = [pgpCryptor signatureDate];
	fprintf(stderr,"GOOD SIGNATURE\n");
	fprintf(stderr,"    Signator:  %s\n",[signator cString]);
	fprintf(stderr,"        Date:  %s\n",[[sigDate description] cString]);
    }
    else if(sigStat == PGP6_NOSIG) {
	fprintf(stderr,"NO SIGNATURE on this document\n");
    }
    else if(sigStat == PGP6_BADSIG) {
	fprintf(stderr,"BAD SIGNATURE\n");
    }
    else if(sigStat == PGP6_SIGNOKEY) {
	fprintf(stderr,"UNVERIFIED SIGNATURE, NO PUBLIC KEY\n");
    }
	

    [pgpCryptor release];
    [pool release];

    exit(0);
}
