/* Copyright (c) 1999 by Howard R. Cole.  All Rights Reserved. */
/* Anyone may use this code for any purpose provide these top  */
/* three lines are not removed from the code                   */

#import <stdio.h>
#import <Foundation/Foundation.h>
#import <pgp.h>

#define PGP6_NOSIG       0
#define PGP6_GOODSIG     1
#define PGP6_BADSIG      2
#define PGP6_SIGNOKEY    3

@interface PGPserver : NSObject
{
    /* PGP home directory and key rings */
    NSString *pgpHomeDir;
    NSString *secRingFile;
    NSString *pubRingFile;
    NSString *pgpCfg;
    PGPContextRef context;
    PGPKeySetRef keyRingSet;

    /* Option flags */
    BOOL doSignature;
    BOOL detachSignature;
    BOOL clearSign;
    BOOL doArmor;
    BOOL doTextTranslation;
    BOOL doConventionalOnly;
    BOOL useUntrusted;
    BOOL encryptToSelf;

    /* signature results */
    int signatureStatus;
    NSString *signator;
    NSDate *signatureDate;

    /* new key results */
    NSString *newKeyUserID;
    NSString *newKeyFingerprint;

    /* Entropy bits */
    int *entropyBucket;
    int entropyLength;
}

- init;
- (void)dealloc;

- openKeyringFiles:(BOOL)writeFlag;
- pgpHomeDir:(NSString *)newHome writeable:(BOOL)writeFlag;
- pgpPublicRingFile:(NSString *)newPubRing writeable:(BOOL)writeFlag;
- pgpSecretRingFile:(NSString *)newSecRing writeable:(BOOL)writeFlag;


/***************************************  PGP OPTION METHODS ***********************************/

- doSignature:(BOOL)useSig;
- clearSign:(BOOL)flag;
- detachSignature:(BOOL)detach;
- encryptToSelf:(BOOL)flag;
- doConventionalOnly:(BOOL)flag;
- doArmor:(BOOL)useArmor;
- doTextTranslation:(BOOL)useText;
- useUntrustedKeys:(BOOL)untrustedFlag;

- (BOOL)doConventionalOnly;
- (BOOL)clearSign;


/***************************************  ENCRYPTION METHODS ***********************************/

- (NSData *)encryptData:(NSData *)plainText 
                      withKeys:(NSMutableArray *)userIDArray
                    passPhrase:(NSString *)passPhraseString
                         error:(int *)errorCode;


- encryptFile:(NSString *)plainFile toFile:(NSString *)cipherFile 
                           withKeys:(NSMutableArray *)userIDArray
                         passPhrase:(NSString *)passPhraseString
                              error:(int *)errorCode;


/***************************************  DECRYPTION METHODS ***********************************/

- (NSData *)decryptData:(NSData *)cipherText 
                    passPhrase:(NSString *)phraseString
                         error:(int *)errorCode;


- decryptFile:(NSString *)cipherFile passPhrase:(NSString *)phraseString
                                      plainFile:(NSString *)plainFileString
                                          error:(int *)errorCode;




/******************************  CREATING SIGNATURE METHODS ***********************************/

- (NSData *)signData:(NSData *)docData 
                 passPhrase:(NSString *)phraseString
                      error:(int *)errorCode;

- signFile:(NSString *)docFile toFile:(NSString *)signedFile 
                           passPhrase:(NSString *)phraseString
                                error:(int *)errorCode;


/******************************  VERIFYING SIGNATURE METHODS ***********************************/

- (NSData *)verifySignatureData:(NSData *)docData
                     passPhrase:(NSString *)phraseString
                          error:(int *)errorCode;

- (NSData *)verifySignatureFile:(NSString *)docFile
                     passPhrase:(NSString *)phraseString
                          error:(int *)errorCode;

- verifyDetachedSignatureData:(NSData *)sigData
                  againstData:(NSData *)docData
                   passPhrase:(NSString *)phraseString
                        error:(int *)errorCode;

- verifyDetachedSignatureFile:(NSString *)sigFile
 		  againstFile:(NSString *)docFile
                   passPhrase:(NSString *)phraseString
                        error:(int *)errorCode;

- signatureStatus:(int)newStatus;
- signator:(NSString *)newSignator;
- signatureDate:(NSDate *)signatureDate;

- (int)signatureStatus;
- (NSString *)signator;
- (NSDate *)signatureDate;


/***************************************  KEY MANAGEMENT METHODS ***********************************/

- (int)userIDExists:(NSString *)userID error:(int *)errorCode;
- (NSMutableArray *)getAllUserIDs:(int *)errorCode;
- (NSMutableArray *)getUserIDsMatching:(NSString *)userID error:(int *)errorCode;
- (NSString *)fingerprintForUserID:(NSString *)userID error:(int *)errorCode;

- importKeyData:(NSData *)keyData error:(int *)errorCode;
- importKeyFile:(NSString *)keyFile error:(int *)errorCode;

- (NSData *)exportKeyData:(NSString *)userID error:(int *)errorCode;

- removeKeyForUserID:(NSString *)userID error:(int *)errorCode;


/*****************************  Extract characteristics from key data ****************************/

- (NSData *)generateNewKeyPair:(NSString *)userID
                       keySize:(PGPUInt32)keySize
                       entropy:(int *)entropyPool
                   entropySize:(int)entropySize
                    passPhrase:(NSString *)passphrase
                         error:(int *)errorCode;

- assessKeyFromData:(NSData *)keyData error:(int *)errorCode;
- setNewKeyUserID:(NSString *)newUserID;
- setNewKeyFingerprint:(NSString *)newKeyFingerprint;

- (NSString *)newKeyUserID;
- (NSString *)newKeyFingerprint;

- setDefaultKey:(NSString *)defaultUserID error:(int *)errorCode;


@end
